/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.cat.tm.core;

import java.util.ArrayList;
import java.util.List;

/**
 * Benten TM (翻訳メモリ) ドライバーを管理するクラス。
 */
public class BentenTmDriverManager {
	/**
	 * 登録されている TM (翻訳メモリ) ドライバーのリスト。
	 */
	protected static final List<BentenTmDriver> fDriverList = new ArrayList<BentenTmDriver>();

	/**
	 * TM ドライバーを登録します。
	 * 
	 * @param driver 登録したい TM ドライバー。
	 */
	public static void registerDriver(final BentenTmDriver driver) {
		if (driver == null) {
			throw new IllegalArgumentException("BentenTmDriverManager#registerDriver: 不正な引数: driver は null であってはなりません。");
		}
		if (driver.getName() == null) {
			throw new IllegalArgumentException(
					"BentenTmDriverManager#registerDriver: 不正な引数: driver#getName は null を戻してはなりません。");
		}

		for (BentenTmDriver look : fDriverList) {
			if (look.getName().equals(driver.getName())) {
				// すでに登録済みのドライバーです。
				// 登録処理をせずに離脱します。
				return;
			}
		}

		fDriverList.add(driver);
	}

	/**
	 * TM ドライバーを登録解除します。
	 * 
	 * @param driver 登録解除したい TM ドライバー。
	 */
	public static void deregisterDriver(final BentenTmDriver driver) {
		if (driver == null) {
			throw new IllegalArgumentException(
					"BentenTmDriverManager#deregisterDriver: 不正な引数: driver は null であってはなりません。");
		}
		if (driver.getName() == null) {
			throw new IllegalArgumentException(
					"BentenTmDriverManager#deregisterDriver: 不正な引数: driver#getName は null を戻してはなりません。");
		}

		for (BentenTmDriver look : fDriverList) {
			if (look.getName().equals(driver.getName())) {
				// 該当するドライバーが発見できました。
				// 除去のうえ離脱します。
				fDriverList.remove(look);
				return;
			}
		}
	}

	/**
	 * 登録されている TM ドライバーの一覧を取得します。
	 * 
	 * @return TM ドライバーの配列。
	 */
	public static BentenTmDriver getDriver(final String driverName) {
		if (driverName == null) {
			throw new IllegalArgumentException("BentenTmDriverManager#getDriver: 不正な引数: driverName は null であってはなりません。");
		}

		for (BentenTmDriver driver : fDriverList) {
			if (driver.getName().equals(driverName)) {
				return driver;
			}
		}

		return null;
	}

	/**
	 * 登録されている TM ドライバーの一覧を取得します。
	 * 
	 * @return TM ドライバーの配列。
	 */
	public static BentenTmDriver[] getDrivers() {
		final BentenTmDriver[] drivers = new BentenTmDriver[fDriverList.size()];
		for (int index = 0; index < fDriverList.size(); index++) {
			drivers[index] = fDriverList.get(index);
		}

		return drivers;
	}
}
