/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.cat.tm.core;

import java.io.File;
import java.io.IOException;
import java.util.List;

/**
 * Benten TM (翻訳メモリ) エンジンをあらわすインタフェース。
 */
public interface BentenTmEngine {
	/**
	 * 指定されたディレクトリ内の TMX 形式のファイルから TM (翻訳メモリ) をロードします。
	 * 
	 * このメソッドを呼ぶと、追加的に TM が構築されます。
	 * 
	 * @param dirTmx TMX 形式のファイルが格納されたディレクトリー。
	 * @throws IOException 入出力例外が発生した場合。
	 */
	void loadTmx(File dirTmx) throws IOException;

	/**
	 * TM (翻訳メモリ) のアンロード。
	 * 
	 * このエンジンが保持している TM を破棄します。
	 */
	void unload();

	/**
	 * あいまい一致 TM 検索結果のリストを取得します。
	 *
	 * @param search ターゲット
	 * @return あいまい一致 TM 検索結果のリスト
	 */
	List<BentenTmSearchResult> fuzzySearch(String search);
}
