/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.cat.tm.engine;

import org.osgi.framework.BundleContext;

import benten.cat.tm.core.BentenTmDriver;
import benten.cat.tm.core.BentenTmEngine;
import benten.core.AbstractBentenPlugin;

/**
 * Benten TM (翻訳メモリ) のための抽象プラグイン。
 * 
 * Benten TM エンジン作成者は、このクラスを継承して実際の TM エンジン・プラグインを提供する必要があります。
 * この抽象クラスを継承し、かつ拡張ポイントを提供しているものが、TM エンジン・プラグインとして動作します。
 * このクラスの中で、Eclipse 拡張ポイントへのアクセスなどを実施します。
 */
public abstract class AbstractBentenTmEnginePlugin extends AbstractBentenPlugin {
	/** 共用インスタンス */
	protected static AbstractBentenTmEnginePlugin plugin;

	/**
	 * このプラグインが利用する TM エンジンのインスタンス。
	 */
	protected BentenTmEngine fEngine = null;

	@Override
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;
	}

	@Override
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		super.stop(context);
	}

	/**
	 * このプラグインの共用インスタンスを取得します。
	 * @return このプラグインの共用インスタンス
	 */
	public static AbstractBentenTmEnginePlugin getDefault() {
		return plugin;
	}

	/**
	 * TM エンジンのドライバーを取得します。
	 * 
	 * @return TM エンジン・ドライバーのインスタンス。
	 */
	public abstract BentenTmDriver getDriver();

	/**
	 * プラグインが保持している TM エンジンのインスタンスを取得します。
	 * 
	 * @return プラグインが保持している TM エンジンのインスタンス。
	 */
	public abstract BentenTmEngine getEngine();

	/**
	 * TM データをロードします。
	 * 
	 * 一般的な処理内容は以下のようになります。
	 * <UL>
	 * <LI>最初にエンジンが保持している TM データをアンロードします。
	 * <LI>拡張ポイント登録一覧から、この TM エンジンが処理可能な拡張ポイントを取得します。
	 * <LI>得られた拡張ポイントから処理可能な拡張のリストを取得します。
	 * <LI>拡張のリストの中で、この TM エンジンが期待する名称の拡張を取得します。
	 * <LI>得られた拡張から、TMX データを読み込みます。
	 * </UL>
	 */
	public abstract void load();
}
